Usage
## S3 method for class 'DirichletRegModel':
print(x, digits = max(3, getOption("digits") - 3), \dots)
## S3 method for class 'DirichletRegModel':
summary(object, \dots)
## S3 method for class 'DirichletRegModel':
fitted(object, mu = TRUE, alpha = FALSE, phi = FALSE, \dots)
## S3 method for class 'DirichletRegModel':
predict(object, newdata, mu = TRUE, alpha = FALSE, phi = FALSE, \dots)
## S3 method for class 'DirichletRegModel':
residuals(object, type = c("standardized", "composite", "raw"), \dots)
## S3 method for class 'DirichletRegModel':
confint(object, parm, level, \dots, type=c("all", "beta", "gamma"), exp = FALSE)
## S3 method for class 'DirichletRegConfint':
print(x, digits = 3, \dots)
## S3 method for class 'DirichletRegModel':
logLik(object, \dots)
## S3 method for class 'DirichletRegModel':
AIC(object, \dots, k = 2)
## S3 method for class 'DirichletRegModel':
BIC(object, \dots)
## S3 method for class 'DirichletRegModel':
nobs(object, \dots)
## S3 method for class 'DirichletRegModel':
vcov(object, \dots)
## S3 method for class 'DirichletRegModel':
update(object, formula., \dots, evaluate = TRUE)Arguments
x
an object of class DirichletRegModel
object
an object of class DirichletRegModel or DirichletRegConfint for printing an object obtained by confint.DirichletRegModel
alpha
logical; returns alpha values
mu
logical; returns expected values
phi
logical; returns precision values
type
for residuals: defines the type of residuals to be computed "standardized" (i.e., Pearson), "composite", or "raw"
for confint: defines the type of parameter ("all"
newdata
a data.frame containing new observations
k
number for the weighting of parameters
parm
a vector containing names of the parameters to print
level
(a vector of) confidence level(s), defaults to .95
exp
logical; returns parameters in exponentiated form
digits
the number of digits in the output
evaluate
if FALSE the updated call will be returned, but not evaluated